#!/bin/bash

# **
# * ------------------------------------------------------------------------
# * BlueMind Stats Portal, aka bm-stats
# * ------------------------------------------------------------------------
# * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
# * @author  : Pascal SALAUN 
# * @Website : http://www.breizh-ltd.com <http://www.breizh-ltd.com>
# * ------------------------------------------------------------------------
# **

PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
export PATH

HOSTNAME=$(hostname -f) 

chmod 644 /etc/cron.d/bm-stats 

# Nginx settings
echo "Adding the vhost bmStats to NGINX "
sed -i "s/__externalUrl__/$HOSTNAME/" /etc/nginx/sites-available/bmStats
cp /etc/nginx/sites-available/bmStats /etc/nginx/sites-enabled/.


#set permissions on /usr/share/bm-stats
/bin/chown -R root.www-data /usr/share/bm-stats
/bin/chmod -R 775 /usr/share/bm-stats
/bin/chmod -R 777 /usr/share/bm-stats/www/tmp

echo "Reloading NGINX..."
/etc/init.d/bm-nginx restart 0>/dev/null 1>/dev/null 2>/dev/null 3>/dev/null || true
 
if [ -d "/var/lib/bm-stats/" ]; then
	echo "Directory /var/lib/bm-stats/ already exists"
else
	echo "Creating directory /var/lib/bm-stats/"
	mkdir -p  /var/lib/bm-stats/general
		
	for thisDir in `du --max-depth=1 /var/spool/cyrus/ | cut -f2 | sed 's/\n//' |sed 's/_/./g' ` ; do
		this=${thisDir##*/}
           
		if [ "$this" != "" -a  "$this" != "mail" -a "$this" != "news" ] ; then
			mkdir -p /var/lib/bm-stats/$this/img
		fi
  	done
	
	/bin/chown -R root.www-data /var/lib/bm-stats/
	/bin/chmod -R 775 /var/lib/bm-stats/
               
fi

    
####  Setting the conf files ####

# Have replace / by # , why? have a look at "## time zone" 
timezone=`cat /etc/timezone |sed 's/\//#/'`  

lang="en" 

if [ "$lang" != "fr" -a "$lang" != "en" ] ; then
        lang="en" ;
fi

#Setting file /usr/share/bm-stats/www/php/conf/config.php
cp /usr/share/bm-stats/www/conf/config.php.sample /usr/share/bm-stats/www/conf/config.php


## Lang
sed -i "s/__lang__/$lang/" /usr/share/bm-stats/www/conf/config.php

## time zone
sed -i "s/__timeZone__/$timezone/" /usr/share/bm-stats/www/conf/config.php
sed -i "/^date_default/s/#/\//" /usr/share/bm-stats/www/conf/config.php

chown root.www-data /usr/share/bm-stats/www/conf/config.php
    

### Setting Logs Management####
# which daemon (rsyslog|syslog-ng|sysklogd) 
DaemomLog=`dpkg -l "*sys*log*" | grep ii | tr -s ' ' | cut -d ' ' -f2 | grep -v system|grep -v lib`
	    
if [ "$DaemomLog" = "rsyslog" ]; then
	if [ -f /etc/logrotate.d/rsyslog ]; then
		echo "Configuring /etc/logrotate.d/rsyslog"
		sed -i 's/\(^\/var\/log\/mail.*\)/#\1/g'  /etc/logrotate.d/rsyslog
	fi
fi

if [ "$DaemomLog" = "syslog-ng" ]; then
	if [ -f /etc/logrotate.d/syslog-ng ]; then
		echo "Configuring /etc/logrotate.d/syslog-ng"
		echo "The previous one saved as /etc/logrotate.d/syslog-ng-bmStats-BacKup.disabled"
		/usr/share/bm-stats/scripts/SHELL/Logrotate-SyslogNG-No-MailLog.sh
	fi
fi

echo "A logrotate of mail.log file will now be done each day at 00:00, and the the filelog \"2 days old\" "
echo "will be moved in /var/log/mail/ ";
echo "See /usr/share/bm-stats/scripts/SHELL/MailLogRotate.sh for details"



### Setting Postfix main.cf####
#
echo "Adding postfix PCRE rules for bmStats" 

testPostfixMimeHeaderCkeck=$(grep -c -e '^mime_header.*BM_mime_header_checks' /etc/postfix/main.cf)
testPostfixHeaderCkeck=$(grep -c -e '^header_checks.*BM_header_checks' /etc/postfix/main.cf)

if [ "$testPostfixMimeHeaderCkeck" != 0 -a "$testPostfixHeaderCkeck" != 0 ]; then
	echo " Postfix : specific bmStats mime_header_check and header_check seems to be loaded "
else
	echo " Saving your actual postif main.cf "
	/bin/cp /etc/postfix/main.cf "/etc/postfix/main.cf_"$(date +%Y%m%d-%H%M%S)"_by_bmStats"

	if [ "$testPostfixMimeHeaderCkeck" = 0 ]; then
		echo "Adding postfix PCRE rules for bmStats" 
		echo "" >> /etc/postfix/main.cf
		echo "#bmStats PCRE Rules" >> /etc/postfix/main.cf
		echo "mime_header_checks= pcre:/etc/postfix/BM_mime_header_checks" >> /etc/postfix/main.cf

        fi

        if [ "$testPostfixHeaderCkeck" = 0 ]; then
		    echo "header_checks= pcre:/etc/postfix/BM_header_checks" >> /etc/postfix/main.cf

        fi    

	echo "Reloading Postfix"
	service postfix reload

fi

exit 0
