#!/bin/bash

# **
# * ------------------------------------------------------------------------
# * BlueMind Stats Portal, aka bm-stats
# * ------------------------------------------------------------------------
# * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
# * @author  : Pascal SALAUN 
# * @Website : http://www.breizh-ltd.com <http://www.breizh-ltd.com>
# * ------------------------------------------------------------------------
# **

PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
export PATH

HOSTNAME=$(hostname -f) 

ln -s /usr/bin/php /usr/bin/php5

chmod 644 /etc/cron.d/bm-stats 


sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/PHP/do_graph/do_graph_attachment.php
sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/PHP/do_graph/do_graph_error.php
sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/PHP/do_graph/do_graph_nbRecip.php
sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/PHP/do_graph/do_graph.php
sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/PHP/do_report/function/divers.php
sed -i 's/www-data/apache/' /usr/share/bm-stats/scripts/SHELL/install.sh
sed -i 's/www-data/apache/' /usr/share/bm-stats/www/function/dir_file.php
sed -i 's/www-data/apache/' /etc/cron.d/bm-stats


# Nginx settings
echo "Adding the vhost bmStats to NGINX "
sed -i "s/__externalUrl__/$HOSTNAME/" /etc/nginx/sites-available/bmStats
cp /etc/nginx/sites-available/bmStats /etc/nginx/sites-enabled/.


#set permissions on /usr/share/bm-stats
/bin/chown -R root.apache /usr/share/bm-stats
/bin/chmod -R 775 /usr/share/bm-stats
/bin/chmod -R 777 /usr/share/bm-stats/www/tmp

echo "Reloading NGINX..."
/etc/init.d/bm-nginx restart 0>/dev/null 1>/dev/null 2>/dev/null 3>/dev/null || true
 
if [ -d "/var/lib/bm-stats/" ]; then
	echo "Directory /var/lib/bm-stats/ already exists"
	/bin/chown -R root.apache /var/lib/bm-stats/
	/bin/chmod -R 775 /var/lib/bm-stats/
else
	echo "Creating directory /var/lib/bm-stats/"
	mkdir -p  /var/lib/bm-stats/general
	
	for thisDir in `du --max-depth=1 /var/spool/cyrus/ | cut -f2 | sed 's/\n//' |sed 's/_/./g' ` ; do
		this=${thisDir##*/}
           
		if [ "$this" != "" -a  "$this" != "mail" -a "$this" != "news" ] ; then
			mkdir -p /var/lib/bm-stats/$this/img
		fi
  	done
	/bin/chown -R root.apache /var/lib/bm-stats/
	/bin/chmod -R 775 /var/lib/bm-stats/
               
fi




    
####  Setting the conf files ####

# Have replace / by # , why? have a look at "## time zone" 
timezone=`cat /etc/sysconfig/clock | cut -d "\"" -f2|sed 's/\//#/'`  

lang="en" 

if [ "$lang" != "fr" -a "$lang" != "en" ] ; then
        lang="en" ;
fi

#Setting file /usr/share/bm-stats/www/php/conf/config.php
cp /usr/share/bm-stats/www/conf/config.php.sample /usr/share/bm-stats/www/conf/config.php


## Lang
sed -i "s/__lang__/$lang/" /usr/share/bm-stats/www/conf/config.php

## time zone
sed -i "s/__timeZone__/$timezone/" /usr/share/bm-stats/www/conf/config.php
sed -i "/^date_default/s/#/\//" /usr/share/bm-stats/www/conf/config.php

chown root.apache /usr/share/bm-stats/www/conf/config.php
    

### Setting Logs Management####
# which daemon (rsyslog|syslog-ng|sysklogd) 
DaemomLog=`yum -q list installed "*sys*log*" |sed 1d | tr -s " "|cut -d"." -f1`
	    
if [ "$DaemomLog" = "rsyslog" ]; then
	if [ -f /etc/logrotate.d/syslog ]; then
		echo "Configuring rsyslog and /etc/logrotate.d/rsyslog"
		sed -i 's/maillog/mail\.log/' /etc/rsyslog.conf
		mv /var/log/maillog /var/log/mail.log
		/etc/init.d/rsyslog restart
		sed -i '/maillog/d' /etc/logrotate.d/syslog
		echo "Restarting rsyslog..."
		etc/init.d/rsyslog restart
	fi
fi

if [ "$DaemomLog" = "syslog-ng" ]; then
	if [ -f /etc/logrotate.d/syslog ]; then
		echo "Configuring syslog-ng and /etc/logrotate.d/syslog-ng"
		sed -i '/maillog/d' /etc/logrotate.d/syslog
		sed -i 's/maillog/mail\.log/' /etc/syslog-ng/syslog-ng.conf
		sed -i 's/LogDaemon="rsyslog"/LogDaemon="syslog-ng"/' /usr/share/bm-stats/scripts/SHELL/MailLogRotate.sh
		echo "Restarting syslog-ng..."
		/etc/init.d/syslog-ng restart
	fi
fi

echo "A logrotate of mail.log file will now be done each day at 00:00, and the the filelog \"2 days old\" "
echo "will be moved in /var/log/mail/ ";
echo "See /usr/share/bm-stats/scripts/SHELL/MailLogRotate.sh for details"



### Setting Postfix main.cf####
#
echo "Adding postfix PCRE rules for bmStats" 

testPostfixMimeHeaderCkeck=$(grep -c -e '^mime_header.*BM_mime_header_checks' /etc/postfix/main.cf)
testPostfixHeaderCkeck=$(grep -c -e '^header_checks.*BM_header_checks' /etc/postfix/main.cf)

if [ "$testPostfixMimeHeaderCkeck" != 0 -a "$testPostfixHeaderCkeck" != 0 ]; then
	echo " Postfix : specific bmStats mime_header_check and header_check seems to be loaded "
else
	echo " Saving your actual postif main.cf "
	/bin/cp /etc/postfix/main.cf "/etc/postfix/main.cf_"$(date +%Y%m%d-%H%M%S)"_by_bmStats"

	if [ "$testPostfixMimeHeaderCkeck" = 0 ]; then
		echo "Adding postfix PCRE rules for bmStats" 
		echo "" >> /etc/postfix/main.cf
		echo "#bmStats PCRE Rules" >> /etc/postfix/main.cf
		echo "mime_header_checks= pcre:/etc/postfix/BM_mime_header_checks" >> /etc/postfix/main.cf

        fi

        if [ "$testPostfixHeaderCkeck" = 0 ]; then
		    echo "header_checks= pcre:/etc/postfix/BM_header_checks" >> /etc/postfix/main.cf

        fi    

	echo "Reloading Postfix"
	/etc/init.d/postfix reload

fi

exit 0
